# CALCOS

Calibration software for HST/COS.

[![CalCOS Pytest](https://github.com/spacetelescope/calcos/actions/workflows/python_testing.yml/badge.svg)](https://github.com/spacetelescope/calcos/actions/workflows/python_testing.yml)
[![test CalCOS](https://github.com/spacetelescope/RegressionTests/actions/workflows/calcos.yml/badge.svg)](https://github.com/spacetelescope/RegressionTests/actions/workflows/calcos.yml)

[Documentation](https://hst-docs.stsci.edu/cosdhb/chapter-3-cos-calibration)
